@@ -170,7 +170,7 @@ on_dialog_add_edit_reponse (GtkWidget *dialog, int response_id,
                             LogviewFilterManager *manager)
 {
   GtkWidget *entry_name, *entry_regex;
-  GtkWidget *radio_color, *radio_visible;
+  GtkWidget *radio_color;
   GtkWidget *check_foreground, *check_background;
   GtkWidget *color_foreground, *color_background;
   gchar *old_name;
@@ -189,8 +189,6 @@ on_dialog_add_edit_reponse (GtkWidget *dialog, int response_id,
                                                     "entry_regex"));
   radio_color = GTK_WIDGET (gtk_builder_get_object (builder,
                                                     "radio_color"));
-  radio_visible = GTK_WIDGET (gtk_builder_get_object (builder,
-                                                      "radio_visible"));
   check_foreground = GTK_WIDGET (gtk_builder_get_object (builder,
                                                          "check_foreground"));
   check_background = GTK_WIDGET (gtk_builder_get_object (builder,
@@ -297,6 +295,7 @@ run_add_edit_dialog (LogviewFilterManager *manager, LogviewFilter *filter)
 
   dialog = GTK_WIDGET (gtk_builder_get_object (builder,
                                                "dialog_filter"));
+  gtk_window_set_title (GTK_WINDOW (dialog), title);
 
   entry_name = GTK_WIDGET (gtk_builder_get_object (builder,
                                                    "entry_name"));
